@@ -9,12 +9,15 @@ subsetData = function(data,search)
 	#colnames(dataout)[1] = "info"
 	# set rownames to marker names
 	rownames(dataout) = data$Marker
-	# remove columns that have no data
-	index = which(apply(dataout,MARGIN=2,FUN=function(x) all(is.na(x))))
-	if(length(index!=0)) dataout = dataout[,-index,drop=FALSE]
 	# remove AMEL data
 	index = which(rownames(dataout)%in%c("AMEL","amel","Amel"))
 	if(length(index)!=0) dataout = dataout[-index,,drop=FALSE]
+	# remove columns that have no data
+	if(!all(is.na(dataout)))
+		{
+		index = which(apply(dataout,MARGIN=2,FUN=function(x) all(is.na(x))))
+		if(length(index!=0)) dataout = dataout[,-index,drop=FALSE]
+		}	
 	return(dataout)
 	}
 
@@ -101,6 +104,7 @@ removeOneRow = function(heightsRow, allelesRow, indexBelow)
   print(paste0("Warning: alleles below detection threshold in locus ",rownames(heightsRow),
                ". Below threshold alleles are being removed. Consider checking input CSP if this is unexpected."))
   indexBelow = (1:length(heightsRow))[-indexBelow]
+  if(length(indexBelow)==0) return(list(rep(NA,length(heightsRow)),rep(NA,length(heightsRow))))
   heightsRow[1:length(indexBelow)] = heightsRow[indexBelow]
   allelesRow[1:length(indexBelow)] = allelesRow[indexBelow]
   heightsRow[(length(indexBelow)+1):length(heightsRow)] = NA
